@@ -27,7 +27,6 @@ impl Event {
                     return ftd::e2(
                         format!("Can't convert value to string {:?}", value),
                         doc.name,
-                        doc.name.to_string(),
                         line_number,
                     );
                 }
@@ -40,11 +39,11 @@ impl Event {
     pub fn get_events(
         line_number: usize,
         events: &[Self],
-        all_locals: &mut ftd_rt::Map,
+        all_locals: &mut ftd::Map,
         arguments: &std::collections::BTreeMap<String, crate::Value>,
         doc: &crate::p2::TDoc,
         root_name: Option<&str>,
-    ) -> crate::p1::Result<Vec<ftd_rt::Event>> {
+    ) -> crate::p1::Result<Vec<ftd::Event>> {
         let arguments = {
             //remove properties
             let mut arguments_without_properties: std::collections::BTreeMap<String, crate::Value> =
@@ -57,7 +56,7 @@ impl Event {
             arguments_without_properties
         };
 
-        let mut event: Vec<ftd_rt::Event> = vec![];
+        let mut event: Vec<ftd::Event> = vec![];
         for e in events {
             let target = match e.action.target.strip_prefix('@') {
                 Some(value) => {
@@ -71,7 +70,6 @@ impl Event {
                         return ftd::e2(
                             format!("Can't find the local variable {}", value),
                             doc.name,
-                            doc.name.to_string(),
                             line_number,
                         );
                     }
@@ -79,9 +77,9 @@ impl Event {
                 None => e.action.target.to_string(),
             };
 
-            event.push(ftd_rt::Event {
+            event.push(ftd::Event {
                 name: e.name.to_str().to_string(),
-                action: ftd_rt::Action {
+                action: ftd::Action {
                     action: e.action.action.to_str().to_string(),
                     target,
                     parameters: ftd::p2::Event::to_value(
@@ -97,12 +95,12 @@ impl Event {
         Ok(event)
     }
 
-    pub fn mouse_event(all_locals: &mut ftd_rt::Map) -> crate::p1::Result<Vec<ftd_rt::Event>> {
-        let mut event: Vec<ftd_rt::Event> = vec![];
+    pub fn mouse_event(all_locals: &mut ftd::Map) -> crate::p1::Result<Vec<ftd::Event>> {
+        let mut event: Vec<ftd::Event> = vec![];
         if let Some(val) = all_locals.get("MOUSE-IN") {
-            event.push(ftd_rt::Event {
+            event.push(ftd::Event {
                 name: "onmouseenter".to_string(),
-                action: ftd_rt::Action {
+                action: ftd::Action {
                     action: "set-value".to_string(),
                     target: format!("@MOUSE-IN@{}", val),
                     parameters: std::array::IntoIter::new([(
@@ -112,9 +110,9 @@ impl Event {
                     .collect(),
                 },
             });
-            event.push(ftd_rt::Event {
+            event.push(ftd::Event {
                 name: "onmouseleave".to_string(),
-                action: ftd_rt::Action {
+                action: ftd::Action {
                     action: "set-value".to_string(),
                     target: format!("@MOUSE-IN@{}", val),
                     parameters: std::array::IntoIter::new([(
@@ -144,14 +142,7 @@ impl EventName {
     pub fn from_string(s: &str, doc_id: &str) -> ftd::p1::Result<Self> {
         match s {
             "click" => Ok(Self::OnClick),
-            t => {
-                return ftd::e2(
-                    format!("{} is not a valid event", t),
-                    doc_id,
-                    doc_id.to_string(),
-                    0,
-                )
-            }
+            t => return ftd::e2(format!("{} is not a valid event", t), doc_id, 0),
         }
     }
 }
@@ -302,7 +293,6 @@ impl Action {
                             action_string, a
                         ),
                         doc.name,
-                        doc.name.to_string(),
                         line_number,
                     );
                 };
@@ -332,7 +322,6 @@ impl Action {
                                         current_parameter, min, idx
                                     ),
                                     doc.name,
-                                    doc.name.to_string(),
                                     line_number,
                                 );
                             }
@@ -352,7 +341,6 @@ impl Action {
                                         max + 1
                                     ),
                                     doc.name,
-                                    doc.name.to_string(),
                                     line_number,
                                 );
                             }
@@ -418,7 +406,6 @@ impl Action {
                 return ftd::e2(
                     format!("{} is not a valid action", t),
                     doc.name,
-                    doc.name.to_string(),
                     line_number,
                 )
             }
@@ -441,7 +428,6 @@ impl Action {
                         return ftd::e2(
                             format!("value not expected {:?}", t),
                             doc.name,
-                            doc.name.to_string(),
                             line_number,
                         )
                     }
