@@ -44,7 +44,6 @@ impl Record {
                     return ftd::e2(
                         format!("'{:?}' ('{}') can not be a sub-section", kind, name),
                         doc.name,
-                        doc.name.to_string(),
                         p1.line_number,
                     );
                 }
@@ -109,18 +108,12 @@ impl Record {
                         }
                     }
                     crate::p2::Kind::Integer { .. } => {
-                        return ftd::e2(
-                            "unexpected integer",
-                            doc.name,
-                            doc.name.to_string(),
-                            p1.line_number,
-                        );
+                        return ftd::e2("unexpected integer", doc.name, p1.line_number);
                     }
                     t => {
                         return ftd::e2(
-                            "not yet implemented",
-                            t,
-                            doc.name.to_string(),
+                            format!("not yet implemented: {:?}", t),
+                            doc.name,
                             p1.line_number,
                         )
                     }
@@ -230,7 +223,7 @@ impl Record {
 
     fn assert_no_extra_fields(
         &self,
-        id: &str,
+        doc_id: &str,
         p1: &crate::p1::Header,
         _caption: &Option<String>,
         _body: &Option<(usize, String)>,
@@ -250,8 +243,7 @@ impl Record {
                         self.name,
                         self.fields.keys()
                     ),
-                    id,
-                    id.to_string(),
+                    doc_id,
                     i.to_owned(),
                 );
             }
@@ -265,7 +257,7 @@ impl Record {
         doc: &crate::p2::TDoc,
         line_number: usize,
     ) -> crate::p1::Result<Self> {
-        let name = ftd_rt::get_name("record", p1_name, doc.name)?;
+        let name = ftd::get_name("record", p1_name, doc.name)?;
         let full_name = doc.format_name(name);
         let mut fields = std::collections::BTreeMap::new();
         let object_kind = (
@@ -340,7 +332,6 @@ fn assert_fields_valid(
                         return ftd::e2(
                             format!("both {} and {} are caption fields", name, c),
                             doc_id,
-                            doc_id.to_string(),
                             line_number,
                         );
                     }
@@ -353,7 +344,6 @@ fn assert_fields_valid(
                         return ftd::e2(
                             format!("both {} and {} are body fields", name, c),
                             doc_id,
-                            doc_id.to_string(),
                             line_number,
                         );
                     }
