@@ -1,6 +1,6 @@
 pub fn parse_import(
     c: &Option<String>,
-    id: &str,
+    doc_id: &str,
     line_number: usize,
 ) -> crate::p1::Result<(String, String)> {
     let v = match c {
@@ -8,8 +8,7 @@ pub fn parse_import(
         None => {
             return ftd::e2(
                 "caption is missing in import statement",
-                id,
-                id.to_string(),
+                doc_id,
                 line_number,
             )
         }
@@ -21,8 +20,7 @@ pub fn parse_import(
             (Some(n), Some(a)) => Ok((n.to_string(), a.to_string())),
             _ => ftd::e2(
                 "invalid use of keyword as in import statement",
-                id,
-                id.to_string(),
+                doc_id,
                 line_number,
             ),
         };
@@ -35,7 +33,7 @@ pub fn parse_import(
     let mut parts = v.rsplitn(2, '/');
     match (parts.next(), parts.next()) {
         (Some(t), Some(_)) => Ok((v.to_string(), t.to_string())),
-        _ => ftd::e2("doc id must contain /", id, id.to_string(), line_number),
+        _ => ftd::e2("doc id must contain /", doc_id, line_number),
     }
 }
 
@@ -43,7 +41,7 @@ pub fn string_and_ref(
     line_number: usize,
     name: &str,
     properties: &std::collections::BTreeMap<String, (crate::Value, Option<String>)>,
-    all_locals: &mut ftd_rt::Map,
+    all_locals: &mut ftd::Map,
     doc_id: &str,
 ) -> crate::p1::Result<(String, Option<String>)> {
     match properties.get(name) {
@@ -52,16 +50,10 @@ pub fn string_and_ref(
         }
         Some(v) => ftd::e2(
             format!("expected string, found: {:?}", v),
-            "string_and_source",
-            doc_id.to_string(),
-            line_number,
-        ),
-        None => ftd::e2(
-            format!("'{}' not found", name),
-            "string_and_source",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
+        None => ftd::e2(format!("'{}' not found", name), doc_id, line_number),
     }
 }
 
@@ -69,7 +61,7 @@ pub fn string_and_source_and_ref(
     line_number: usize,
     name: &str,
     properties: &std::collections::BTreeMap<String, (crate::Value, Option<String>)>,
-    all_locals: &mut ftd_rt::Map,
+    all_locals: &mut ftd::Map,
     doc_id: &str,
 ) -> crate::p1::Result<(String, crate::TextSource, Option<String>)> {
     match properties.get(name) {
@@ -80,23 +72,14 @@ pub fn string_and_source_and_ref(
         )),
         Some(v) => ftd::e2(
             format!("expected string, found: {:?}", v),
-            "string_and_source",
-            doc_id.to_string(),
-            line_number,
-        ),
-        None => ftd::e2(
-            format!("'{}' not found", name),
-            "string_and_source",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
+        None => ftd::e2(format!("'{}' not found", name), doc_id, line_number),
     }
 }
 
-pub fn complete_reference(
-    reference: &Option<String>,
-    all_locals: &mut ftd_rt::Map,
-) -> Option<String> {
+pub fn complete_reference(reference: &Option<String>, all_locals: &mut ftd::Map) -> Option<String> {
     let mut reference = reference.to_owned();
     if let Some(ref r) = reference {
         if let Some(name) = r.strip_prefix('@') {
@@ -129,8 +112,7 @@ pub fn string_optional(
         Some(ftd::Value::None { .. }) => Ok(None),
         Some(v) => ftd::e2(
             format!("expected string, found: {:?}", v),
-            "string_optional",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
         None => Ok(None),
@@ -152,8 +134,7 @@ pub fn string_with_default(
         Some(ftd::Value::None { .. }) => Ok(def.to_string()),
         Some(v) => ftd::e2(
             format!("expected bool, found: {:?}", v),
-            "string_with_default",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
         None => Ok(def.to_string()),
@@ -170,16 +151,10 @@ pub fn int(
         Some(crate::Value::Integer { value: v, .. }) => Ok(*v),
         Some(v) => ftd::e2(
             format!("[{}] expected int, found: {:?}", name, v),
-            "int",
-            doc_id.to_string(),
-            line_number,
-        ),
-        None => ftd::e2(
-            format!("'{}' not found", name),
-            "int",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
+        None => ftd::e2(format!("'{}' not found", name), doc_id, line_number),
     }
 }
 
@@ -195,12 +170,7 @@ pub fn int_optional(
             kind: crate::p2::Kind::Integer { .. },
         }) => Ok(None),
         Some(ftd::Value::None { .. }) => Ok(None),
-        Some(v) => ftd::e2(
-            format!("expected int, found: {:?}", v),
-            "int_optional",
-            doc_id.to_string(),
-            line_number,
-        ),
+        Some(v) => ftd::e2(format!("expected int, found: {:?}", v), doc_id, line_number),
         None => Ok(None),
     }
 }
@@ -218,12 +188,7 @@ pub fn int_with_default(
             kind: crate::p2::Kind::Integer { .. },
         }) => Ok(def),
         Some(ftd::Value::None { .. }) => Ok(def),
-        Some(v) => ftd::e2(
-            format!("expected int, found: {:?}", v),
-            "int_with_default",
-            doc_id.to_string(),
-            line_number,
-        ),
+        Some(v) => ftd::e2(format!("expected int, found: {:?}", v), doc_id, line_number),
         None => Ok(def),
     }
 }
@@ -231,7 +196,7 @@ pub fn int_with_default(
 // pub fn elements(
 //     name: &str,
 //     properties: &std::collections::BTreeMap<String, crate::Value>,
-// ) -> crate::p1::Result<Vec<ftd_rt::Element>> {
+// ) -> crate::p1::Result<Vec<ftd::Element>> {
 //     match properties.get(name) {
 //         Some(crate::Value::Elements(v)) => Ok((*v).clone()),
 //         Some(v) => crate::e(format!("expected elements, found: {:?}", v)),
@@ -254,8 +219,7 @@ pub fn bool_with_default(
         Some(ftd::Value::None { .. }) => Ok(def),
         Some(v) => ftd::e2(
             format!("expected bool, found: {:?}", v),
-            "bool_with_default",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
         None => Ok(def),
@@ -272,16 +236,10 @@ pub fn bool(
         Some(crate::Value::Boolean { value: v, .. }) => Ok(*v),
         Some(v) => ftd::e2(
             format!("[{}] expected bool, found: {:?}", name, v),
-            "string",
-            doc_id.to_string(),
-            line_number,
-        ),
-        None => ftd::e2(
-            format!("'{}' not found", name),
-            "bool",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
+        None => ftd::e2(format!("'{}' not found", name), doc_id, line_number),
     }
 }
 
@@ -306,8 +264,7 @@ pub fn string_bool_optional(
         }
         Some(v) => ftd::e2(
             format!("expected bool, found: {:?}", v),
-            "bool_optional",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
         None => Ok((None, None)),
@@ -347,16 +304,10 @@ pub fn decimal(
         Some(crate::Value::Decimal { value: v, .. }) => Ok(*v),
         Some(v) => ftd::e2(
             format!("[{}] expected Decimal, found: {:?}", name, v),
-            "string",
-            doc_id.to_string(),
-            line_number,
-        ),
-        None => ftd::e2(
-            format!("'{}' not found", name),
-            "decimal",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
+        None => ftd::e2(format!("'{}' not found", name), doc_id, line_number),
     }
 }
 
@@ -374,8 +325,7 @@ pub fn decimal_optional(
         Some(ftd::Value::None { .. }) => Ok(None),
         Some(v) => ftd::e2(
             format!("expected decimal, found: {:?}", v),
-            "decimal_optional",
-            doc_id.to_string(),
+            doc_id,
             line_number,
         ),
         None => Ok(None),
@@ -421,10 +371,7 @@ pub fn reorder(p1: &[ftd::p1::Section], doc_id: &str) -> ftd::p1::Result<Vec<ftd
                         doc_id,
                     );
                 }
-                if let Ok(root) = v
-                    .header
-                    .string(doc_id.to_string(), v.line_number, "component")
-                {
+                if let Ok(root) = v.header.string(doc_id, v.line_number, "component") {
                     if !is_kernel_component(root.to_string()) && !inserted.contains(&root) {
                         reorder_component(p1_map, new_p1, Some(root), inserted, doc_id);
                     }
@@ -451,10 +398,7 @@ pub fn reorder(p1: &[ftd::p1::Section], doc_id: &str) -> ftd::p1::Result<Vec<ftd
                     doc_id,
                 );
             }
-            if let Ok(root) = v
-                .header
-                .string(doc_id.to_string(), v.line_number, "component")
-            {
+            if let Ok(root) = v.header.string(doc_id, v.line_number, "component") {
                 if !is_kernel_component(root.to_string()) && !inserted.contains(&root) {
                     reorder_component(p1_map, new_p1, Some(root), inserted, doc_id);
                 }
@@ -481,11 +425,11 @@ pub fn reorder(p1: &[ftd::p1::Section], doc_id: &str) -> ftd::p1::Result<Vec<ftd
             inserted_p1.push(idx);
             new_p1.push(p1.to_owned());
             if p1.name.starts_with("list ") {
-                let list = ftd_rt::get_name("list", p1.name.as_str(), doc_id)?.to_string();
+                let list = ftd::get_name("list", p1.name.as_str(), doc_id)?.to_string();
                 list_or_var.push(list);
             }
             if p1.name.starts_with("var ") {
-                let var = ftd_rt::get_name("var", p1.name.as_str(), doc_id)?.to_string();
+                let var = ftd::get_name("var", p1.name.as_str(), doc_id)?.to_string();
                 list_or_var.push(var);
             }
         }
@@ -497,7 +441,7 @@ pub fn reorder(p1: &[ftd::p1::Section], doc_id: &str) -> ftd::p1::Result<Vec<ftd
 
         if p1.name.starts_with("component ") {
             p1_map.insert(
-                ftd_rt::get_name("component", p1.name.as_str(), doc_id)?.to_string(),
+                ftd::get_name("component", p1.name.as_str(), doc_id)?.to_string(),
                 p1.to_owned(),
             );
             inserted_p1.push(idx);
